@@ -7,7 +7,7 @@
 #pragma once
 
 // Qt
-#include <QApplication>
+#include <QGuiApplication>
 
 // Utils
 #include <utils/d_ptr.h>
@@ -21,7 +21,7 @@ class Features;
  * This can *not* be a QGuiApplication because
  * we need KWindowSystem widgets.
  */
-class Application : public QApplication
+class Application : public QGuiApplication
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.ActivityManager.Application")
@@ -39,11 +39,12 @@ public:
     Activities &activities() const;
     Features &features() const;
 
+    QString serviceVersion() const;
+    QStringList loadedPlugins() const;
+
 public Q_SLOTS:
     void quit();
-    QString serviceVersion() const;
     bool loadPlugin(const QString &plugin);
-    QStringList loadedPlugins() const;
 
 private Q_SLOTS:
     void init();
